diff --git a/requirements-swh.txt b/requirements-swh.txt
--- a/requirements-swh.txt
+++ b/requirements-swh.txt
@@ -1,5 +1,5 @@
 swh.core >= 0.3
-swh.model >= 4.3.0
+swh.model >= 4.4.0
 swh.objstorage >= 0.2.2
 swh.scheduler >= 0.4.0
 swh.storage >= 0.29.0
diff --git a/swh/loader/package/deposit/tests/test_deposit.py b/swh/loader/package/deposit/tests/test_deposit.py
--- a/swh/loader/package/deposit/tests/test_deposit.py
+++ b/swh/loader/package/deposit/tests/test_deposit.py
@@ -330,11 +330,12 @@
     # Retrieve the release
     release = loader.storage.release_get([hash_to_bytes(release_id)])[0]
     assert release
     # swh-deposit uses the numeric 'offset' instead of 'offset_bytes' because its dates
     # are always well-formed, and it can only send JSON-serializable data.
     release_date_dict = {
         "timestamp": release.date.timestamp.to_dict(),
-        "offset": release.date.offset,
+        "offset": release.date.offset_minutes(),
     }
 
     assert release_date_dict == raw_meta["deposit"]["author_date"]
@@ -330,11 +330,12 @@
     release = loader.storage.release_get([hash_to_bytes(release_id)])[0]
     assert release
-    # swh-deposit uses the numeric 'offset' instead of 'offset_bytes' because its dates
-    # are always well-formed, and it can only send JSON-serializable data.
+    # swh-deposit uses the numeric 'offset_minutes' instead of the bytes offset
+    # attribute, because its dates are always well-formed, and it can only send
+    # JSON-serializable data.
     release_date_dict = {
         "timestamp": release.date.timestamp.to_dict(),